@@ -27,9 +27,8 @@ import json
 import logging
 from typing import Any, Dict
 
-import pkg_resources
-
 from ..cli.load_arguments_from_dataclass import extract_fields_from_class
+from ..tests.utils import exitclose_file_creator
 from .diffusion.core import (
     DiffusionDataArguments,
     DiffusionForVisionTrainingPipeline,
@@ -208,16 +207,14 @@ def training_pipeline_name_to_metadata(name: str) -> Dict[str, Any]:
     Returns:
         dictionary describing the parameters of the pipeline. If the pipeline is not found, no metadata (a.k.a., an empty dictionary is returned).
     """
+
     metadata: Dict[str, Any] = {"training_pipeline": name, "parameters": {}}
     if name in TRAINING_PIPELINE_NAME_METADATA_MAPPING:
         try:
-            with open(
-                pkg_resources.resource_filename(
-                    "gt4sd",
-                    f"training_pipelines/{TRAINING_PIPELINE_NAME_METADATA_MAPPING[name]}",
-                ),
-                "rt",
-            ) as fp:
+            path = exitclose_file_creator(
+                f"training_pipelines/{TRAINING_PIPELINE_NAME_METADATA_MAPPING[name]}"
+            )
+            with open(path, "rt") as fp:
                 metadata["parameters"] = json.load(fp)
         except Exception:
             logger.exception(
